@@ -8,9 +8,7 @@
         args <- as.list(match.call(.Contlcmm))[-1]
 
         nom.subject <- as.character(subject)
-#### INCLUSION PRIOR
-        nom.prior <- as.character(args$prior)
-        nom.data <- as.character(args$data)
+
 
 ####
         if(!missing(mixture) & ng==1) stop("No mixture can be specified with ng=1")
@@ -29,7 +27,8 @@
         if(class(classmb)!="formula") stop("The argument classmb must be a formula")
         if(missing(data)){ stop("The argument data should be specified and defined as a data.frame")} 
         if(missing(subject)){ stop("The argument subject must be specified in any model even without random-effects")} 
-
+        if(!is.numeric(data[,subject])) stop("The argument subject must be numeric")
+        
         ## garder data tel quel pour le renvoyer
         if(returndata==TRUE)
         {
@@ -289,7 +288,7 @@
 #### INCLUSION PRIOR 
         if(missing(prior)){ PRIOR <- seq(0,length=length(IND))} 
         if(!missing(prior)){ 
-            PRIOR <- newdata[,nom.prior]
+            PRIOR <- newdata[,prior]
             PRIOR[(is.na(PRIOR))] <- 0
         }
 ####
@@ -747,6 +746,52 @@
             }
         
 
+        ## faire wRandom et b0Random
+        NEF2 <- sum(idg0!=0)-1
+        NPM2 <- NEF2+NVC+ntrtot0+ncor0
+        wRandom <- rep(0,NPM)
+        b0Random <- rep(0,ng-1) # nprob 
+        
+        l <- 0
+        t <- 0
+        for (i in 1:nvar.exp)
+        {
+            if(idg0[i]==1)
+            {
+                if(i==1) next
+                l <- l+1
+                t <- t+1
+                wRandom[NPROB+t] <- l
+            }
+            if(idg0[i]==2)
+            {
+                if(i==1)
+                {
+                    t <- t+ng-1
+                    b0Random <- c(b0Random,rep(0,ng-1))
+                    next
+                }
+                l <- l+1
+                for (g in 1:ng)
+                {
+                    t <- t+1
+                    wRandom[NPROB+t] <- l
+                }
+            }
+        }
+
+        if(NVC>0)
+        {
+            wRandom[NPROB+NEF+1:NVC] <- NEF2+1:NVC
+        }
+        if(NW>0)
+        {
+            b0Random <- c(b0Random,rep(1,ng-1))
+        }
+        wRandom[NPROB+NEF+NVC+NW+1:ntrtot0] <- NEF2+NVC+1:ntrtot0
+        if (ncor0>0) {wRandom[NPROB+NEF+NVC+NW+ntrtot0+1:ncor0] <- NEF2+NVC+ntrtot0+1:ncor0}
+        ## wRandom et b0Random ok.
+        
         ##------------------------------------------
         ##------nom au vecteur best
         ##--------------------------------------------
@@ -965,7 +1010,7 @@
 ### ad 2/04/2012
         if (!("intercept" %in% nom.X0)) X0.names2 <- X0.names2[-1]
 ### ad
-        res <-list(ns=ns0,ng=ng0,idea0=idea0,idprob0=idprob0,idg0=idg0,idcor0=idcor0,loglik=out$loglik,best=out$best,V=V,gconv=out$gconv,conv=out$conv,call=call,niter=out$niter,N=N,idiag=idiag0,pred=pred,pprob=ppi,predRE=predRE,Xnames=nom.X0,Xnames2=X0.names2,cholesky=Cholesky,estimlink=estimlink,epsY=epsY,linktype=idlink0,linknodes=zitr,Ydiscrete=Ydiscrete,discrete_loglik=out$vraisdiscret,UACV=out$UACV,IndivContrib=out$rlindiv,na.action=na.action,AIC=2*(length(out$best)-length(posfix)-out$loglik),BIC=(length(out$best)-length(posfix))*log(ns0)-2*out$loglik,data=datareturn)
+        res <-list(ns=ns0,ng=ng0,idea0=idea0,idprob0=idprob0,idg0=idg0,idcor0=idcor0,loglik=out$loglik,best=out$best,V=V,gconv=out$gconv,conv=out$conv,call=call,niter=out$niter,N=N,idiag=idiag0,pred=pred,pprob=ppi,predRE=predRE,Xnames=nom.X0,Xnames2=X0.names2,cholesky=Cholesky,estimlink=estimlink,epsY=epsY,linktype=idlink0,linknodes=zitr,Ydiscrete=Ydiscrete,discrete_loglik=out$vraisdiscret,UACV=out$UACV,IndivContrib=out$rlindiv,na.action=na.action,AIC=2*(length(out$best)-length(posfix)-out$loglik),BIC=(length(out$best)-length(posfix))*log(ns0)-2*out$loglik,data=datareturn,wRandom=wRandom,b0Random=b0Random)
         class(res) <- c("lcmm") 
 
         cost <- proc.time()-ptm
