@@ -1,3 +1,6 @@
+#' @rdname predictY
+#' @export
+#'
 predictY.multlcmm <- function(x,newdata,var.time,methInteg=0,nsim=20,draws=FALSE,ndraws=2000,na.action=1,...)
 {
 if(missing(newdata)) stop("The argument newdata should be specified")
@@ -26,10 +29,18 @@ if(x$conv==1 | x$conv==2 | x$conv==3)
 
  
   ##pour les facteurs
-  olddata <- eval(x$call$data)
+  ##donnees de l estimation
+  if(!is.null(x$data))
+  {
+      olddata <- x$data
+  }
+  else
+    {
+        olddata <- eval(x$call$data)
+    }
   termes <- x$Xnames[-1]
   
-   #cas ou une variable dans le dataset du modele est un facteur
+  #cas ou une variable dans le dataset du modele est un facteur
    for(v in x$Xnames2[-1])
    {
     if (is.factor(olddata[,v]))
@@ -109,7 +120,7 @@ if(x$conv==1 | x$conv==2 | x$conv==3)
   {                                                                              
    newdata <- as.data.frame(newdata[-linesNA,])
    colnames(newdata) <- x$Xnames2
-   times <- times[-linesNA]
+   times <- times[-linesNA,,drop=FALSE]
   }
   
  
