@@ -344,45 +344,45 @@ void F77_SUB(cvpl)(double * Y0,
 		   int * npm0);
 
 void F77_SUB(postprob2)(double * Y0, 
-			     double * Xdata0, 
-			     int * ns0,
-			     int * nmes0,
-			     int * nobs0,
-			     int * ng0,
-			     int * nv0,
-			     int * idiag0,
-			     int * nwg0,
-			     int * ncor0,
-			     int * logspecif0,
-			     double * zi0,
-			     int * idea0,
-			     int * idg0,
-			     int * idprob0,
-			     int * idcor0, 
-			     int * idcom0,
-			     int * idspecif0,
-			     int * idtdv0,
-			     int * risqcom0,
-			     int * nvdepsurv0,
-			     int * typrisq0,
-			     int * nz0,
-			     int * nprisq0,
-			     int * nbzitr0,
-			     double zitr0,
-			     int * idlink0,
-			     int * indiceY0,
-			     double * uniqueY0,
-			     int * nvalSPL0,
-			     double * epsY0,
-			     int * nbevt0,
-			     double * tsurv00,
-			     int * idtrunc0,
-			     double * b,
-			     int * npm0,
-			     double * timemes,
-			     double * landmark,
-			     int * nbland,
-			     double * ppi);
+			double * Xdata0, 
+			int * ns0,
+			int * nmes0,
+			int * nobs0,
+			int * ng0,
+			int * nv0,
+			int * idiag0,
+			int * nwg0,
+			int * ncor0,
+			int * logspecif0,
+			double * zi0,
+			int * idea0,
+			int * idg0,
+			int * idprob0,
+			int * idcor0, 
+			int * idcom0,
+			int * idspecif0,
+			int * idtdv0,
+			int * risqcom0,
+			int * nvdepsurv0,
+			int * typrisq0,
+			int * nz0,
+			int * nprisq0,
+			int * nbzitr0,
+			double * zitr0,
+			int * idlink0,
+			int * indiceY0,
+			double * uniqueY0,
+			int * nvalSPL0,
+			double * epsY0,
+			int * nbevt0,
+			double * tsurv00,
+			int * idtrunc0,
+			double * b,
+			int * npm0,
+			double * timemes,
+			double * landmark,
+			int * nbland,
+			double * ppi);
 
 void F77_SUB(calculustransfo)(double * b,
 			       int * npm,
@@ -401,3 +401,68 @@ void F77_SUB(calculustransfo)(double * b,
 			       int * dimide,
 			       double * transfY);
 
+void F77_SUB(mpjhet)(int * K0,
+		     int * ny0,
+		     int * nbevt0,
+		     int * ng0,
+		     int * ns0,
+		     double * Y0,
+		     int * nobs0,
+		     double * X0,
+		     int * nv0,
+		     double * Xns0,
+		     int * nv20,
+		     int * prior0,
+		     double * Tentr0,
+		     double * Tevt0,
+		     int * Devt0,
+		     int * ind_survint,
+		     int * idnv0,
+		     int * idnv20,
+		     int * idspecif0,
+		     int * idlink0,
+		     double * epsY0,
+		     int * nbzitr0,
+		     double * zitr0,
+		     double * uniqueY0,
+		     int * nvalSPL0,
+		     int * indiceY0,
+		     int * typrisq0,
+		     int * risqcom0,
+		     int * nz0,
+		     double * zi0,
+		     int * nmes0,
+		     int * nea0,
+		     int * nw0,
+		     int * ncor0,
+		     int * nalea0,
+		     int * idiag0,
+		     int * int3,
+		     int * npmtot0,
+		     double * btot,
+		     double * Vopt,
+		     double * vrais,
+		     int * ni,
+		     int * istop,
+		     double * gconv,
+		     double * ppi0,
+		     double * ppitest0,
+		     double * resid_m,
+		     double * resid_ss,
+		     double * pred_m_g,
+		     double * pred_ss_g,
+		     double * pred_RE,
+		     double * pred_RE_Y,
+		     double * convBLG,
+		     double * time,
+		     double * risq_est,
+		     double * risqcum_est,
+		     double * marker,
+		     double * transfY,
+		     int * nsim,
+		     double * Yobs,
+		     double * statscoretest,
+		     int * pbH0,
+		     int * fix0,
+		     int * contrainte);
+		     
